/// @file ilmsens_hal_defn.h 
/// @brief Macro definitions for Ilmsens HAL
///
/// This header contains definitions for various values used in different HAL functions.
///
/// @author Ralf Herrmann <ralf.herrmann@ilmsens.com>

/* ILMsens UWB HAL API

   This header contains definitions used in the API calls.
   
   Platform: C/C++
   Author  : R. Herrmann
   
   Revision:
     
     1.0.0: (01/2017)

     + initial revision containing only run modes and debug levels.
*/

#pragma once

///////////////////////////////////////////////////////////////////////////////////////////////////
// global definitions for UWB HAL API
///////////////////////////////////////////////////////////////////////////////////////////////////

#include "ilmsens_hal_version.h"

/**
  * @addtogroup ilmsens_hal_meas_run
  *
  * @{
  */
#define ILMSENS_HAL_RUN_OFF                  0              ///< sensor is currently not measuring 
#define ILMSENS_HAL_RUN_RAW                  1              ///< sensor is measuring and data is not buffered by API 
#define ILMSENS_HAL_RUN_BUF                  2              ///< sensor is measuring and data is buffered by API in separate thread 

/** @} */


/**
  * @addtogroup ilmsens_hal_modinfo
  *
  * @{
  */

#define ILMSENS_HAL_MOD_ID_BUF_SIZE          1024           ///< maximum length buffer size for retrieving the unique ID string.

/** @} */


/**
  * @addtogroup ilmsens_hal_config
  *
  * @{
  */

#define ILMSENS_HAL_SLAVE_SENSOR               0           ///< setup the sensor(s) to be slave devices
#define ILMSENS_HAL_MASTER_SENSOR              1           ///< setup the sensor(s) to be master devices

/** @} */


/**
  * @addtogroup ilmsens_hal_meas_config
  *
  * @{
  */

#define ILMSENS_HAL_SYNCH_OFF                  0           ///< retract digital synchronisation, i.e. sensors will be unsynch'ed
#define ILMSENS_HAL_SYNCH_ON                   1           ///< perform digital synchronisation, i.e. sensors will be synch'ed

#define ILMSENS_HAL_TX_OFF                     1           ///< transmitter is in power down mode, i.e. output amplifier is switch off
#define ILMSENS_HAL_TX_ON                      0           ///< transmitter is working, i.e. output amplifier is switched on

/** @} */


/**
  * @addtogroup ilmsens_hal_diag
  *
  * @{
  */

#define ILMSENS_DEB_NO                   0U                 ///< do not output debug/info messages
#define ILMSENS_DEB_INFO                 1U                 ///< only output errors and very important information
#define ILMSENS_DEB_MORE                 2U                 ///< output errors, warnings, and important information
#define ILMSENS_DEB_MOST                 3U                 ///< output errors, warnings, and debug information
#define ILMSENS_DEB_ALL                  4U                 ///< output errors, warnings, and trace information

/** @} */
